
"""
 Copyright (C) 2007, 2008 Eric Ehlers

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
"""

"""Global configuration state for gensrc application."""

from gensrc.utilities import common
from gensrc.utilities import utilities
from gensrc.serialization import serializable

class Configuration(serializable.Serializable):
    """Global configuration state for gensrc application."""

    #############################################
    # public interface
    #############################################

    def libRootDirectory(self):
        """Return the root directory of the library application."""
        return self.libRootDirectory_

    def namespaceObjects(self):
        """Return the namespace of classes inherited from
        ObjectHandler::Object."""
        return self.namespaceObjects_

    def namespaceLibrary(self):
        """Return the namespace of the library application."""
        return self.namespaceLibrary_

    def usingEnumerations(self):
        """Return a flag indicating whether source code is to be generated
        for enumerated datatypes."""
        return self.usingEnumerations_

    def usingSerialization(self):
        """Return a flag indicating whether source code is to be generated
        for serialization functionality."""
        return self.usingSerialization_

    def prefix(self):
        """Return text to be prefixed to addin function names."""
        return self.prefix_

    def prefixExcel(self):
        """Return text to be prefixed to functions in the Excel addin."""
        return self.prefixExcel_

    def relativePath(self):
        """Return the path of the current working directory relative to the
        root directory of the application."""
        return self.relativePath_

    def copyrightBuffer(self):
        """Return the buffer containing the copyright message to be included
        in autogenerated source code."""
        return self.copyrightBuffer_

    #############################################
    # serializer interface
    #############################################

    def serialize(self, serializer):
        """Load/unload class state to/from serializer object."""

        serializer.serializeProperty(self, 'libRootDirectory')
        serializer.serializeProperty(self, common.NAMESPACE_OBJ)
        serializer.serializeProperty(self, common.NAMESPACE_LIB)
        serializer.serializeProperty(self, 'prefix')
        serializer.serializeProperty(self, 'prefixExcel')
        serializer.serializeBoolean(self, 'usingEnumerations')
        serializer.serializeBoolean(self, 'usingSerialization')
        serializer.serializeProperty(self, 'relativePath')

    #############################################
    # private member functions
    #############################################

    def __init__(self):
        """Initialize the application configuration."""

        # load copyright buffer
        fileBuffer = open('stubs/stub.copyright')
        self.copyrightBuffer_ = fileBuffer.read()
        fileBuffer.close()

