
"""
 Copyright (C) 2005, 2006, 2007 Eric Ehlers
 Copyright (C) 2005 Plamen Neykov
 Copyright (C) 2005 Aurelien Chanudet

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
"""

"""Encapsulate state and behavior required to generate source code for a
function."""

from gensrc.utilities import common
from gensrc.utilities import buffer
from gensrc.serialization import serializable
from gensrc.functions import behavior
from gensrc.parameters import parameterlist
from gensrc.parameters import parameter
from gensrc.configuration import environment

# possible states for the implementation of a function on a given platform
DOC_ONLY = 0    # only autogenerate documentation for this function - no code
MANUAL = 1      # function hand-written - registration may be autogenerated
AUTO = 2        # autogenerate all code and documentation (the default)

class SupportedPlatform(serializable.Serializable):
    """Define the implementation of a particular function on a particular 
    platform."""

    #############################################
    # class variables
    #############################################

    groupName_ = 'SupportedPlatforms'

    # map to take the implementation as a string loaded from XML metadata
    # and convert it to one of the constants defined above
    implStrToInt = {
        'documentationOnly' : DOC_ONLY,
        'manual' : MANUAL,
        'auto' : AUTO }

    #############################################
    # public interface
    #############################################

    def implNum(self):
        """Return the constant which corresponds to the string describing this
        platform."""
        return self.implNum_

    def xlMacro(self):
        """Return a boolean indicating whether this Addin function should
        acquire macro capabilities on the Excel platform."""
        return self.xlMacro_

    def calcInWizard(self):
        """Return a boolean indicating whether this Addin function should
        execute under the Function Wizard  on the Excel platform."""
        return self.calcInWizard_

    #############################################
    # serializer interface
    #############################################

    def serialize(self, serializer):
        """Load/unload class state to/from serializer object."""
        serializer.serializeAttribute(self, common.NAME)
        serializer.serializeAttribute(self, common.IMPLEMENTATION, 'auto')
        serializer.serializeAttributeBoolean(self, common.XL_MACRO, True)
        serializer.serializeAttributeBoolean(self, common.CALC_IN_WIZARD, True)

    def postSerialize(self):
        """Derive the integer constant associated with the deserialized
        string."""
        self.implNum_ = SupportedPlatform.implStrToInt[self.implementation_]

